@@ -85,7 +85,12 @@ class QuotaSetsController(wsgi.Controller):
             auth_url=CONF.keystone_authtoken.auth_uri,
             token=context.auth_token,
             project_id=context.project_id)
-        client_session = session.Session(auth=auth_plugin)
+        ca_check = CONF.keystone_authtoken.cafile or True
+        client_session = session.Session(auth=auth_plugin,
+                                         verify=False
+                                         if CONF.keystone_authtoken.insecure
+                                         else ca_check)
+
         return client.Client(auth_url=CONF.keystone_authtoken.auth_uri,
                              session=client_session)
 
